@@ -4,7 +4,6 @@ from pprint import pformat
 from time import sleep
 
 import requests
-from requests import HTTPError
 from six import wraps
 from six.moves.urllib.parse import urljoin
 from six.moves.urllib.parse import urlparse
@@ -17,7 +16,7 @@ DEFAULT_TIMEOUT = 180
 class ProviderHTTPClientException(Exception):
     def __init__(self, *args, **kwargs):
         super(ProviderHTTPClientException, self).__init__(*args)
-        for key, value in kwargs:
+        for key, value in kwargs.items():
             setattr(self, key, value)
 
 
@@ -129,42 +128,45 @@ class ProviderRequestProxy(object):
                 logger.exception('Failed to decode json file with error message: %s', e)
                 return {}
         else:
-            return response.content()
+            return response.content
 
     def request_with_retry(self, method, **request_arguments):
         request_arguments = self.augment_request_arguments(**request_arguments)
         retries = 0
+        retry_errors = []
 
         while retries < self.retries:
             try:
                 response = getattr(requests, method)(**request_arguments)
-                try:
-                    if 400 <= response.status_code < 500:
-                        http_error_msg = '%s Client Error: %s for url: %s %s' % \
-                                         (response.status_code,
-                                          response.reason,
-                                          response.url,
-                                          response.content)
-                        raise ProviderHTTPClientException(http_error_msg)
-                    # TODO: add more retryable exceptions code
-                    elif response.status_code in [502, 503]:
-                        raise RetryableException('Deployment in progress')
-                    elif 500 <= response.status_code < 600:
-                        response.raise_for_status()
-                except HTTPError as exc:
-                    logger.exception(response.content)
-                    raise
+                if 400 <= response.status_code < 500:
+                    http_error_msg = '%s Client Error: %s for url: %s %s' % \
+                                     (response.status_code,
+                                      response.reason,
+                                      response.url,
+                                      response.content)
+                    raise ProviderHTTPClientException(http_error_msg)
+                # TODO: add more retryable exceptions code
+                elif response.status_code in [502, 503]:
+                    raise RetryableException('Deployment might be in progress, or server is overloaded')
+                elif 500 <= response.status_code < 600:
+                    raise ProviderHTTPClientException('%d Server error. %s ' % (
+                        response.status_code,
+                        response.reason
+                    ), response=response)
 
-            except (requests.Timeout, RetryableException):
+            except (requests.Timeout, RetryableException) as exc:
                 logger.debug('Retry request %s %s', method, request_arguments['url'])
                 retries += 1
+                retry_errors.append(exc)
                 sleep(self.retry_delay)
-            except requests.ConnectionError as e:
-                raise ProviderHTTPServiceException('Service is not working with error: %s' % e)
+            except requests.ConnectionError as exc:
+                retry_errors.append(exc)
+                raise ProviderHTTPServiceException('Service is not working with error: %s' % exc)
             else:
                 break  # Exits while loop
         else:
-            raise ProviderHTTPServiceException('Failed to do request after {} tries'.format(MAX_RETRIES))
+            raise ProviderHTTPServiceException('Failed to do request after {} tries'.format(MAX_RETRIES),
+                                               retries=retry_errors)
 
         return self.format_return_data(response)
 
@@ -174,8 +176,8 @@ def remote_service(path, headers=None, timeout=None, json=True, raw=False):
         headers = {}
     assert isinstance(headers, dict), 'Headers should be a dict!'
 
-    safe_methods = ['get', 'head', 'options']
-    unsafe_methods = ['post', 'put', 'patch', 'delete']
+    # safe_methods = ['get', 'head', 'options']
+    # unsafe_methods = ['post', 'put', 'patch', 'delete']
 
     def wrapper(func):
         @wraps(func)
