@@ -41,6 +41,12 @@ def test_processing_action_group_invoke():
     result = runner.invoke(api, ['processing-action', 'download'])
 
 
+def test_configure_command():
+    runner = CliRunner()
+    from rebotics_sdk.cli.retailer import api
+    result = runner.invoke(api, ['-r', 'local', 'configure'])
+
+
 def test_camera_settings_add_roi():
     runner = CliRunner()
     from rebotics_sdk.cli.shelf_camera_manager import api
